@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::FlatAuth;
 
 # ABSTRACT: Authentication using Flat Files for PlugAuth
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 
 use strict;
@@ -191,7 +191,7 @@ sub change_password
         my $line = <$fh>;
         chomp $line;
         my($thisuser, $oldpassword) = split /:/, $line;
-        if(lc($thisuser) eq $user)
+        if(defined $thisuser && lc($thisuser) eq $user)
         {
           $buffer .= join(':', $user, $password) . "\n";
         }
@@ -259,7 +259,7 @@ PlugAuth::Plugin::FlatAuth - Authentication using Flat Files for PlugAuth
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
