@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::FlatAuthz;
 
 # ABSTRACT: Authorization using flat files for PlugAuth
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 
 use strict;
@@ -272,7 +272,7 @@ sub delete_group
       my $line = <$fh>;
       chomp $line;
       my($thisgroup, $password) = split /\s*:/, $line;
-      next if lc $thisgroup eq $group;
+      next if defined $thisgroup && lc $thisgroup eq $group;
       $buffer .= "$line\n";
     }
 
@@ -312,7 +312,7 @@ sub update_group
       my $line = <$fh>;
       chomp $line;
       my($thisgroup) = split /\s*:/, $line;
-      $line =~ s{:.*$}{: $users} if lc($thisgroup) eq $group;
+      $line =~ s{:.*$}{: $users} if defined $thisgroup && lc($thisgroup) eq $group;
       $buffer .= "$line\n";
     }
     $buffer;
@@ -349,7 +349,7 @@ sub add_user_to_group
       my $line = <$fh>;
       chomp $line;
       my($thisgroup, $users) = split /\s*:\s*/, $line;
-      if(lc($thisgroup) eq $group)
+      if(defined $thisgroup && lc($thisgroup) eq $group)
       {
         $users = join ',', uniq (split(/\s*,\s*/, $users), $user);
         $buffer .= "$thisgroup: $users\n";
@@ -395,7 +395,7 @@ sub remove_user_from_group
       my $line = <$fh>;
       chomp $line;
       my($thisgroup, $users) = split /\s*:\s*/, $line;
-      if(lc($thisgroup) eq $group)
+      if(defined $thisgroup && lc($thisgroup) eq $group)
       {
         $users = join ',', grep { lc($_) ne $user } uniq @{ $self->users_in_group($group) };
         $buffer .= "$thisgroup: $users\n";
@@ -553,7 +553,7 @@ PlugAuth::Plugin::FlatAuthz - Authorization using flat files for PlugAuth
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
