@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::FlatUserList;
 
 # ABSTRACT: PlugAuth plugin that provides a user list without authentication.
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 
 use strict;
@@ -34,7 +34,7 @@ sub all_users
   if($mtime != $self->{mtime})
   {
     open(my $fh, '<', $self->{filename});
-    my @list = <$fh>;
+    my @list = grep !/^\s*$/, <$fh>;
     chomp @list;
     close $fh;
     $self->{mtime} = $mtime;
@@ -57,7 +57,7 @@ PlugAuth::Plugin::FlatUserList - PlugAuth plugin that provides a user list witho
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
