@@ -12,7 +12,7 @@ use File::Spec;
 use File::Touch qw( touch );
 
 # ABSTRACT: private role used by L<FlatAuth|PlugAuth::Plugin::FlatAuth> and L<FlatAuthz|PlugAuth::Plugin::FlatAuthz>.
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 my %MTimes;
 
@@ -56,7 +56,7 @@ sub read_file { # TODO: cache w/ mtime
   #
   TRACE "reading $filename";
   my %h;
-  my $fh = IO::File->new("<$filename");
+  open my $fh, '<', $filename;
   flock($fh, LOCK_SH) or WARN "Cannot lock $filename - $!\n";
   for my $line ($fh->getlines)
   {
@@ -192,7 +192,7 @@ PlugAuth::Role::Flat - private role used by L<FlatAuth|PlugAuth::Plugin::FlatAut
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SEE ALSO
 
